/**
 * @longmo/vue2-helpers
 *
 * @description A util package to use Vue 2 with Composition API easily
 * @version 2.3.0
 * @license Apache-2.0
 * @see {@link https://github.com/longmo/vue2-helpers#readme}
 * @experimental
 *
 * Build: 2024-11-09T16:04:27.229Z
 */
import { isVue2, h as h$1 } from 'vue-demi';

/**
 * h-demi - h function for Vue 2 and 3
 *
 * @see {@link https://github.com/vueuse/vue-demi/issues/65}
 * @experimental
 */
/**
 * `on` functions glue of  Vue2 and Vue3
 *
 * @param ons `on` functions
 */
const adaptOnsV3 = (ons) => {
    if (!ons)
        return {};
    return Object.entries(ons).reduce((ret, [key, handler]) => {
        key = key.charAt(0).toUpperCase() + key.slice(1);
        key = `on${key}`;
        return { ...ret, [key]: handler };
    }, {});
};
/**
 * hDemi function.
 *
 * @param type - Tag name etc
 * @param options - VNode data.
 * @param children - Children dom or VNode component
 */
const h = (type, options = {}, children = undefined) => {
    if (isVue2) {
        return h$1(type, options, children);
    }
    const ons = options.on ? adaptOnsV3(options.on) : {};
    return h$1(type, { ...options.props, ...options.domProps, ...ons }, children);
};
/**
 * slots
 *
 * @param defaultSlots -
 */
const slot = (defaultSlots) => typeof defaultSlots === 'function' ? defaultSlots() : defaultSlots;

export { h, slot };
//# sourceMappingURL=h-demi.es.js.map
