/**
 * @longmo/vue2-helpers
 *
 * @description A util package to use Vue 2 with Composition API easily
 * @version 2.3.0
 * @license Apache-2.0
 * @see {@link https://github.com/longmo/vue2-helpers#readme}
 *
 * Build: 2024-11-09T16:04:27.331Z
 */
import { Vue2, getCurrentInstance, effectScope, reactive } from 'vue-demi';
import VueRouter from 'vue-router';

const { warn } = console;
const OUT_OF_SCOPE = 'getCurrentInstance() returned null. Method must be called at the top of a setup() function.';
const DEPRECATED_ROUTER = (name) => `${name}() is deprecated. use "import { ${name} } from 'vue-router/composables';"`;

// @ts-expect-error add isReady function to VueRouter
VueRouter.prototype.isReady = async function () {
    await new Promise((resolve, reject) => {
        this.onReady(resolve, reject);
    });
};
/** Create Vue Router */
function createRouter(options) {
    Vue2?.use(VueRouter);
    return new VueRouter(options);
}
/**
 * Get Router instance
 *
 * @deprecated use `vue-router/composables`.
 */
function useRouter() {
    warn(`[vue2-helpers/vue-router] ${DEPRECATED_ROUTER('useRouter')}`);
    const inst = getCurrentInstance();
    if (inst) {
        return inst.proxy.$root.$router;
    }
    warn(`[vue2-helpers/vue-router] ${OUT_OF_SCOPE}`);
    return undefined;
}
let currentRoute;
/**
 * Get current route instance
 *
 * @deprecated use `vue-router/composables`.
 */
function useRoute() {
    warn(`[vue2-helpers/vue-router] ${DEPRECATED_ROUTER('useRoute')}`);
    const router = useRouter();
    if (!router) {
        return undefined;
    }
    if (!currentRoute) {
        const scope = effectScope(true);
        scope.run(() => {
            currentRoute = reactive(assign({}, router.currentRoute));
            router.afterEach(to => {
                assign(currentRoute, to);
            });
        });
    }
    return currentRoute;
}
/**
 * Attach leave current route event
 *
 * @deprecated use `vue-router/composables`.
 * @param leaveGuard - Navigation Guard
 * @returns
 */
function onBeforeRouteLeave(leaveGuard) {
    warn(`[vue2-helpers/vue-router] ${DEPRECATED_ROUTER('onBeforeRouteLeave')}`);
    const inst = getCurrentInstance();
    if (inst == null) {
        warn(`[vue2-helpers/vue-router] ${OUT_OF_SCOPE}`);
        return;
    }
    const { options } = inst.proxy.constructor;
    const hooks = options.beforeRouteLeave || [];
    hooks.push(leaveGuard);
    options.beforeRouteLeave = hooks;
}
/**
 * Attach route before update event
 *
 * @deprecated use `vue-router/composables`.
 * @param updateGuard - Navigation Guard
 * @returns
 */
function onBeforeRouteUpdate(updateGuard) {
    warn(`[vue2-helpers/vue-router] ${DEPRECATED_ROUTER('onBeforeRouteUpdate')}`);
    const inst = getCurrentInstance();
    if (inst == null) {
        warn(`[vue2-helpers/vue-router] ${OUT_OF_SCOPE}`);
        return;
    }
    const { options } = inst.proxy.constructor;
    const hooks = options.beforeRouteUpdate || [];
    hooks.push(updateGuard);
    options.beforeRouteUpdate = hooks;
}
/**
 *
 * @param target -
 * @param source -
 * @returns
 */
function assign(target, source) {
    Object.keys(source).forEach(key => (target[key] = source[key]));
    return target;
}

export { createRouter, onBeforeRouteLeave, onBeforeRouteUpdate, useRoute, useRouter };
//# sourceMappingURL=vue-router.es.js.map
