/**
 * @longmo/vue2-helpers
 *
 * @description A util package to use Vue 2 with Composition API easily
 * @version 2.3.0
 * @license Apache-2.0
 * @see {@link https://github.com/longmo/vue2-helpers#readme}
 *
 * Build: 2024-11-09T16:04:27.374Z
 */
import { Vue2, getCurrentInstance } from 'vue-demi';
import Vuetify from 'vuetify/lib';

const { warn } = console;
const OUT_OF_SCOPE = 'getCurrentInstance() returned null. Method must be called at the top of a setup() function.';

/** Create Vuetify Instance */
function createVuetify(options) {
    Vue2?.use(Vuetify);
    return new Vuetify(options);
}
/** Vuetify Instance */
function useVuetify() {
    /** Vue instance */
    const instance = getCurrentInstance();
    if (instance?.proxy) {
        return instance?.proxy.$vuetify;
    }
    warn(`[vue2-helpers/vuetify] ${OUT_OF_SCOPE}`);
    return undefined;
}
/** Use Display */
function useDisplay() {
    return useVuetify().breakpoint;
}
/** Theme */
function useTheme() {
    return useVuetify().theme;
}

export { createVuetify, useDisplay, useTheme, useVuetify };
//# sourceMappingURL=vuetify.es.js.map
