/**
 * @longmo/vue2-helpers
 *
 * @description A util package to use Vue 2 with Composition API easily
 * @version 2.3.0
 * @license Apache-2.0
 * @see {@link https://github.com/longmo/vue2-helpers#readme}
 *
 * Build: 2024-11-09T16:04:27.388Z
 */
import Vuex, { Store } from 'vuex';
import { Vue2, getCurrentInstance } from 'vue-demi';

const { warn } = console;
const OUT_OF_SCOPE = 'getCurrentInstance() returned null. Method must be called at the top of a setup() function.';

/** Create Vuex Store */
function createStore(options) {
    Vue2?.use(Vuex);
    return new Store(options);
}
/** Get Vuex Instance */
function useStore() {
    const inst = getCurrentInstance();
    if (inst != null) {
        return inst.proxy.$store;
    }
    else {
        warn(`[vue2-helpers/vuex] ${OUT_OF_SCOPE}`);
    }
    return undefined;
}

export { createStore, useStore };
//# sourceMappingURL=vuex.es.js.map
